/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TRMOSC demo for the TOSHIBA
 *          'TMPM374' Device Series 
 * @version 0.0.0.1
 * @date    2014/09/25
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "stdio.h"
#include "tmpm374_trmosc.h"
#include "gpio.h"
#include "tmrb.h"
#include "IOSCadjustment.h"

/* Private define ------------------------------------------------------------*/
#define		COUNTMAX	(10)		/* retry counter max value1 */
/* Private variable -----------------------------------------------*/
uint32_t	RetryCount=0;
int32_t		AdjustResult;

/**
  * @brief  The main function of TRMOSC demo
  * @param  None
  * @retval None
  */
int main(void)
{
	uint32_t tmp, i;

	InitGpio();
	InitTMRB3();
	InitTMRB6();

	InitialTRMOSC();					/* for debug */

	printf("%s\r\n", "---------------");
	printf("%s\r\n", "| TRMOSC_demo |");
	printf("%s\r\n", "---------------");

	printf("%s\r\n", "please wait...");
	for(i=0; i<0x00400000; i++);
	printf("%s\r\n", "---------------");
	printf("%s\r\n", "|    start    |");
	printf("%s\r\n", "---------------");

	for(RetryCount=0; RetryCount <= COUNTMAX; RetryCount++) {
		AdjustResult = IOSCAdjustment();
		if (AdjustResult == TRMOSC_DONE) {
			printf("%s\r\n", "TRMOSC_DONE");
			if(GetTrimmingControlValue() == TRMOSC_CONTROL_ENABLE) {
				tmp = GetCoarseTrimValueSet();
				printf("%s%X\r\n", "<TRIMSETC>:", tmp);
				tmp = GetFineTrimValueSet();
				printf("%s%X\r\n", "<TRIMSETF>:", tmp);
			}
			else {
				printf("%s\r\n", "Inital trimming Value");
			}
			break;
		}
		else if (AdjustResult == TRMOSC_RUN) {
			printf("%s\r\n", "TRMOSC_RUN");
			if(GetTrimmingControlValue() == TRMOSC_CONTROL_ENABLE) {
				tmp = GetCoarseTrimValueSet();
				printf("%s%X\r\n", "<TRIMSETC>:", tmp);
				tmp = GetFineTrimValueSet();
				printf("%s%X\r\n", "<TRIMSETF>:", tmp);
			}
			else {
				printf("%s\r\n", "Inital trimming Value");
			}
		}
		else {
			printf("%s\r\n", "TRMOSC_ERROR");
		}
	}

	while(1);
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
