/** 
 *******************************************************************************
 * @file    tmrb.c
 * @brief   the application functions of TRMOSC demo for the TOSHIBA
 *          'TMPM374' Device Series 
 * @version 0.0.0.1
 * @date    2014/09/25
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "stdint.h"
#include "tmpm374_tmrb.h"

/* Private define ------------------------------------------------------------*/
#define TMRB3COUNT	(0x00000001UL)
#define TMRB6COUNT	(0x0000FFFFUL)

/**
  * @brief  initialize TMBR3
  * @param  None
  * @retval None
  */
void InitTMRB3(void)
{
    TMRB_InitTypeDef m_tmrb;
	TMRB_FFOutputTypeDef m_tmrb_ff;

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_2;
    m_tmrb.TrailingTiming = TMRB3COUNT;
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.LeadingTiming = TMRB3COUNT;

	m_tmrb_ff.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
	m_tmrb_ff.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB3);
    TMRB_Init(TSB_TB3, &m_tmrb);
	TMRB_SetFlipFlop(TSB_TB3, &m_tmrb_ff);
    TMRB_SetRunState(TSB_TB3, TMRB_RUN);
}

/**
  * @brief  initialize TMBR6
  * @param  None
  * @retval None
  */
void InitTMRB6(void)
{
    TMRB_InitTypeDef m_tmrb;

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_2;
    m_tmrb.TrailingTiming = TMRB6COUNT;
    m_tmrb.UpCntCtrl = TMRB_FREE_RUN;
    m_tmrb.LeadingTiming = TMRB6COUNT;

    TMRB_Enable(TSB_TB6);
    TMRB_Init(TSB_TB6, &m_tmrb);
	TMRB_SetCaptureTiming(TSB_TB6, TMRB_CAPTURE_IN_RISING);
	TMRB_SetExtStartTrg(TSB_TB6, ENABLE, TMRB_TRG_EDGE_FALLING);
    TMRB_SetRunState(TSB_TB6, TMRB_STOP);
}

/**
  * @brief  Start Capture
  * @param  None
  * @retval None
  */
void StartCapture(void)
{
    TMRB_SetRunState(TSB_TB6, TMRB_STOP);
	NVIC_ClearPendingIRQ(INTCAP60_IRQn);
    TMRB_SetRunState(TSB_TB6, TMRB_RUN);
}

/**
  * @brief  Get Capture Data
  * @param  None
  * @retval Capture Data
  */
uint32_t GetCaptureData(void)
{
	uint32_t retval;

	for(;;){
		if (NVIC_GetPendingIRQ(INTCAP60_IRQn)) {
			retval = (uint32_t)TMRB_GetCaptureValue(TSB_TB6, TMRB_CAPTURE_0);
			break;
		}
		else {
			/* do nothing */
		}
	}
	NVIC_ClearPendingIRQ(INTCAP60_IRQn);

	return(retval);
}

/**
  * @brief  Stop Capture
  * @param  None
  * @retval None
  */
void StopCapture(void)
{
    TMRB_SetRunState(TSB_TB6, TMRB_STOP);
	NVIC_ClearPendingIRQ(INTCAP60_IRQn);
}
